@@ -8,7 +8,7 @@ use Time::Local qw//;
 use POSIX qw//;
 use base qw/Exporter/;
 
-our $VERSION = "0.13";
+our $VERSION = "0.30";
 our @EXPORT_OK = qw/strftime/;
 
 use constant {
@@ -343,7 +343,7 @@ sub compile {
         }
         ~ . $sprintf_code . q~
         ~ . $need9char_code . q~
-        POSIX::strftime(q!~ . $posix_fmt . q~!,int($_[0]),@_[1..$#_]);
+        POSIX::strftime(q!~ . $posix_fmt . q~!,@_);
     }~;
     my $sub = eval $code; ## no critic
     die $@ ."\n=====\n".$code."\n=====\n" if $@;
